@@ -136,24 +136,24 @@ void KVerbosApp::initActions()
   userUsername = new KAction(i18n("&Username..."), 0, 0, this, SLOT(slotSettingsUsername()), actionCollection(), "user_username");
   userResults = new KAction(i18n("&Results"), 0, 0, this, SLOT(slotUserResults()), actionCollection(), "user_results");
  
-  fileNewWindow->setStatusText(i18n("Opens a new application window"));
-  fileOpenStandard->setStatusText(i18n("Opens the standard KVerbos verb file"));
-  fileNew->setStatusText(i18n("Creates a new document"));
-  fileOpen->setStatusText(i18n("Opens an existing document"));
-  fileOpenRecent->setStatusText(i18n("Opens a recently used file"));
-  fileSave->setStatusText(i18n("Saves the actual document"));
-  fileSaveAs->setStatusText(i18n("Saves the actual document as..."));
-  fileClose->setStatusText(i18n("Closes the actual document"));
-  filePrint ->setStatusText(i18n("Prints out the actual document"));
-  fileQuit->setStatusText(i18n("Quits the application"));
-  editCut->setStatusText(i18n("Cuts the selected section and puts it to the clipboard"));
-  editCopy->setStatusText(i18n("Copies the selected section to the clipboard"));
-  editPaste->setStatusText(i18n("Pastes the clipboard contents to actual position"));
-  editErfassen->setStatusText(i18n("Add new verbs."));
-  editBearbeiten->setStatusText(i18n("Edit the list of verbs."));
-  settingOptions->setStatusText(i18n("Change some options of the program"));
-  userUsername->setStatusText(i18n("Enter your name as the username"));
-  userResults->setStatusText(i18n("These are your latest results."));
+  fileNewWindow->setToolTip(i18n("Opens a new application window"));
+  fileOpenStandard->setToolTip(i18n("Opens the standard KVerbos verb file"));
+  fileNew->setToolTip(i18n("Creates a new document"));
+  fileOpen->setToolTip(i18n("Opens an existing document"));
+  fileOpenRecent->setToolTip(i18n("Opens a recently used file"));
+  fileSave->setToolTip(i18n("Saves the actual document"));
+  fileSaveAs->setToolTip(i18n("Saves the actual document as..."));
+  fileClose->setToolTip(i18n("Closes the actual document"));
+  filePrint ->setToolTip(i18n("Prints out the actual document"));
+  fileQuit->setToolTip(i18n("Quits the application"));
+  editCut->setToolTip(i18n("Cuts the selected section and puts it to the clipboard"));
+  editCopy->setToolTip(i18n("Copies the selected section to the clipboard"));
+  editPaste->setToolTip(i18n("Pastes the clipboard contents to actual position"));
+  editErfassen->setToolTip(i18n("Add new verbs."));
+  editBearbeiten->setToolTip(i18n("Edit the list of verbs."));
+  settingOptions->setToolTip(i18n("Change some options of the program"));
+  userUsername->setToolTip(i18n("Enter your name as the username"));
+  userResults->setToolTip(i18n("These are your latest results."));
 
   // icons
   editBearbeiten->setIcon("edit.png");
