@@ -1,17 +1,14 @@
 /***************************************************************************
 
-    $Id: MySpinBox.cpp 290564 2004-02-23 15:02:57Z annma $
-
          display special spinbox (only meaningful for QT2x)
 
     -----------------------------------------------------------------------
 
-    begin                : Sat Oct 21 18:02:16 1999
-                                           
-    copyright            : (C) 1999-2001 Ewald Arnold
-                           (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+    begin          : Sat Oct 21 18:02:16 1999
+
+    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001 The KDE-EDU team
+                     (C) 2005 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -30,9 +27,7 @@
 
 #include "MySpinBox.h"
 
-MySpinBox::MySpinBox (QWidget* parent, const char* name ) :
-    QSpinBox(parent, name ),
-    spin_names (0)
+MySpinBox::MySpinBox (QWidget* parent, const char* name ): QSpinBox(parent, name ), spin_names (0)
 {
   setWrapping(true);
 }
@@ -40,8 +35,8 @@ MySpinBox::MySpinBox (QWidget* parent, const char* name ) :
 
 void MySpinBox::setData (QStringList *names, int minValue, int maxValue)
 {
-   spin_names = names;
-   setRange (minValue, maxValue);
+  spin_names = names;
+  setRange (minValue, maxValue);
 }
 
 
@@ -57,7 +52,7 @@ QString MySpinBox::mapValueToText( int value )
 }
 
 
-int MySpinBox::MySpinBox::mapTextToValue( bool* ok )
+int MySpinBox::MySpinBox::mapTextToValue(bool *)
 {
   return 0;
 }
@@ -65,8 +60,8 @@ int MySpinBox::MySpinBox::mapTextToValue( bool* ok )
 
 void MySpinBox::setSpecial(const QString &str)
 {
-   special_str = str;
-   setSuffix("");  // update display
+  special_str = str;
+  setSuffix("");  // update display
 }
 
 
